@@ -3,6 +3,9 @@ from typedtuples.utils import toString
 class TypedTuple:
     def __init__(self, *args, **kwargs):
         self.initialize(args, kwargs)
+        self.init()
+
+    def init(self): return
     
     def initialize(self, args, kwargs):
         a = self.__annotations__
